@@ -3,13 +3,12 @@ from os import getenv
 
 import requests
 
-from examtool.api import get_token, refresh_token
+from examtool.api.auth import get_token, refresh_token
 
 
 def server_only(func):
     @wraps(func)
-    def wrapped(*args, **kwargs):
-        kwargs.update(dict(zip(func.__code__.co_varnames, args)))
+    def wrapped(**kwargs):
         if getenv("ENV") == "SERVER":
             return func(**kwargs)
         else:
@@ -34,4 +33,4 @@ def call_server(method, kwargs):
     elif resp.status_code == 401:
         raise PermissionError
     else:
-        raise Exception
+        raise Exception(resp.text)
